# Far-field Antenna Patterns
A set of classes that define the far-field pattern of antenna
arrays and methods to plot them.

## Installation
You can install the module using pip

    pip install Antennass

## How to use
You can access the class definition by importing the arrays module:

    from arrays import *

You could also use the provided command line interface to generate the plots:

    antennass-cli

